@@ -4,7 +4,7 @@ use 5.008006;
 use strict;
 use warnings;
 
-our $VERSION = '0.17_02';
+our $VERSION = '0.17_03';
 
 use utf8;
 use IO::Socket;
@@ -18,10 +18,12 @@ use constant {
 
 Debug::Client - client side code for perl debugger
 
-development version 0.17_02 for testing only!
+development version 0.17_03 for testing only!
 
 thanks cpan testers :)
 
+Warning if you use List request you may get spourios results
+
 =head1 SYNOPIS
 
   use Debug::Client;
@@ -593,22 +595,22 @@ sub list_break_watch_action {
 	return ( $prompt, \@breakpoints );
 }
 
-=head2 execute_code
+# =head2 execute_code
 
-  $debugger->execute_code($some_code_to_execute);
+# #   $debugger->execute_code($some_code_to_execute);
 
-=cut
+# # =cut
 
-sub execute_code {
-	my ( $self, $code ) = @_;
+# sub execute_code {
+	# my ( $self, $code ) = @_;
 
-	return if not defined $code;
+# # 	return if not defined $code;
 
-	$self->_send($code);
-	my $buf = $self->_get;
-	$self->_prompt( \$buf );
-	return $buf;
-}
+# # 	$self->_send($code);
+	# my $buf = $self->_get;
+	# $self->_prompt( \$buf );
+	# return $buf;
+# }
 
 =head2 get_value
 
@@ -1152,8 +1154,12 @@ __END__
 
 =head1 BUGS AND LIMITATIONS
 
+When using against perl5db.pl v1.35 list mode gives an undef response, also leading single quote now correct. 
+Tests are skiped for list mode against v1.35 now.
+
 Debug::Client 0.12 tests are failing, due to changes in perl debugger, 
 when using perl5db.pl v1.34
+
 Debug::Client 0.13_01 skips added to failing tests.
 
  c [line|sub]
